@@ -8,10 +8,10 @@ import com.ozacc.mail.Mail;
 import com.ozacc.mail.MailBuilder;
 
 /**
- * SendMailImpl饹Υƥȥºݤ᡼顼ǼƳǧƥȤǤ
+ * SendMailImplクラスのテストケース。実際に送信し、メーラーで受信して確認するテストです。
  * 
  * @author Tomohiro Otsuka
- * @version $Id: SendMailImplRealTest.java,v 1.6 2004/09/20 21:44:01 otsuka Exp $
+ * @version $Id: SendMailImplRealTest.java,v 1.6.2.1 2005/01/23 06:51:56 otsuka Exp $
  */
 public class SendMailImplRealTest extends TestCase {
 
@@ -19,6 +19,8 @@ public class SendMailImplRealTest extends TestCase {
 
 	private String email;
 
+	private String envelopeTo;
+
 	private SendMailImpl sendMail;
 
 	/*
@@ -30,8 +32,9 @@ public class SendMailImplRealTest extends TestCase {
 		BasicConfigurator.configure();
 
 		email = "to@example.com";
+		envelopeTo = "to@example.com";
 
-		String host = "192.168.0.10";
+		String host = "localhost";
 		sendMail = new SendMailImpl(host);
 		sendMail.setMessageId("example.com");
 
@@ -45,7 +48,8 @@ public class SendMailImplRealTest extends TestCase {
 		BasicConfigurator.resetConfiguration();
 	}
 
-	/*	public void testSendMailWithAttachmentInputStream() throws Exception {
+	/*
+	 public void testSendMailWithAttachmentInputStream() throws Exception {
 	 String classPath = "/com/ozacc/mail/test-mail4.xml";
 	 Mail mail = builder.buildMail(classPath);
 	 mail.addTo(email);
@@ -53,12 +57,21 @@ public class SendMailImplRealTest extends TestCase {
 	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
 	 FileInputStream fis = new FileInputStream(image1);
 
-	 mail.addFile(fis, "ڲ.jpg");
-	 mail.setSubject("źեեInputStreamƥ");
+	 mail.addFile(fis, "野菜画像.jpg");
+	 mail.setSubject("添付ファイルのInputStream送信テスト");
 
 	 sendMail.send(mail);
 	 }
 
+	 
+	 public void testSendMailEnvelopeTo() throws Exception {
+	 String classPath = "/com/ozacc/mail/test-mail4.xml";
+	 Mail mail = builder.buildMail(classPath);
+	 mail.addTo(email);
+	 mail.addEnvelopeTo(envelopeTo);
+	 sendMail.send(mail);
+	 }
+
 	 public void testSendMailSimpl() throws Exception {
 	 String classPath = "/com/ozacc/mail/test-mail4.xml";
 	 Mail mail = builder.buildMail(classPath);
@@ -76,8 +89,8 @@ public class SendMailImplRealTest extends TestCase {
 	 File image2 = new File("src/test/com/ozacc/mail/image2.png");
 
 	 mail.addFile(image1);
-	 mail.addFile(image2, "ڲ.png");
-	 mail.setSubject("źեեƥ");
+	 mail.addFile(image2, "野菜画像.png");
+	 mail.setSubject("添付ファイル送信テスト");
 
 	 sendMail.send(mail);
 	 }
@@ -87,7 +100,7 @@ public class SendMailImplRealTest extends TestCase {
 	 Mail mail = builder.buildMail(classPath);
 	 mail.addTo(email);
 	 mail.setHtmlText(mail.getText());
-	 mail.setText("ץ졼ƥ");
+	 mail.setText("プレーンテキスト");
 	 sendMail.send(mail);
 	 }
 	 
@@ -97,7 +110,7 @@ public class SendMailImplRealTest extends TestCase {
 	 mail.addTo(email);
 	 mail.setHtmlText(mail.getText());
 	 mail.setText(null);
-	 mail.setSubject("HTML꡼");
+	 mail.setSubject("HTMLオンリー");
 	 sendMail.send(mail);
 	 }
 
@@ -106,7 +119,7 @@ public class SendMailImplRealTest extends TestCase {
 	 Mail mail = builder.buildMail(classPath);
 	 mail.addTo(email);
 	 mail.setHtmlText(mail.getText());
-	 mail.setText("ץ졼ƥ");
+	 mail.setText("プレーンテキスト");
 
 	 File image1 = new File("src/test/com/ozacc/mail/image1.jpg");
 	 mail.addFile(image1);
@@ -115,7 +128,7 @@ public class SendMailImplRealTest extends TestCase {
 	 }
 	 */
 	/**
-	 * ƥȥҤȤĤʤȥ顼ˤʤΤǡߡ
+	 * テストケースがひとつもないとエラーになるので、ダミー。
 	 */
 	public void testSendMailSuccess() {
 		Mail mail;
